// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
// This module is a shim for the plugin consumer in the browser
export function useIdentityPlugin(_plugin) {
    throw new Error("Identity plugins are not supported in browser environments.");
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@azure/identity/dist/browser/plugins/consumer-browser.mjs.map