export class TaskCancelledError extends Error {
    /**
     * Error thrown when a task is cancelled.
     */
    constructor(message = 'Operation cancelled') {
        super(message);
        this.message = message;
        this.isTaskCancelledError = true;
    }
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/cockatiel/dist/esm/errors/TaskCancelledError.js.map