"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExtensionSignatureVerificationError = void 0;
class ExtensionSignatureVerificationError extends Error {
    constructor(code, didExecute, output) {
        super();
        this.code = code;
        this.didExecute = didExecute;
        this.output = output;
    }
}
exports.ExtensionSignatureVerificationError = ExtensionSignatureVerificationError;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/node-ovsx-sign/lib/utils/errors.js.map