/*! @azure/msal-browser v5.6.2 2026-03-27 */
'use strict';
/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
const noStateInHash = "no_state_in_hash";
const unableToParseState = "unable_to_parse_state";
const invalidBase64String = "invalid_base64_string";
const timedOut = "timed_out";
const emptyResponse = "empty_response";

export { emptyResponse, invalidBase64String, noStateInHash, timedOut, unableToParseState };
//# sourceMappingURL=BrowserAuthErrorCodes.mjs.map
