/** @file Types used in signatures of Cheerio methods. */
export {};//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/cheerio/dist/browser/types.js.map