// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export {};//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@azure/identity/dist/esm/credentials/multiTenantTokenCredentialOptions.js.map