// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export { useInstrumenter } from "./instrumenter.js";
export { createTracingClient } from "./tracingClient.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@azure/core-tracing/dist/esm/index.js.map