import { EventEmitter } from './Event';
const emitter0 = new EventEmitter();
const emitter1 = new EventEmitter();
emitter1.addListener(() => undefined);
const emitter3 = new EventEmitter();
emitter3.addListener(() => undefined);
emitter3.addListener(() => undefined);
emitter3.addListener(() => undefined);
bench('0 listener', () => emitter0.emit(true));
bench('1 listener', () => emitter1.emit(true));
bench('3 listener', () => emitter3.emit(true));//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/cockatiel/dist/esm/common/Executor.bench.js.map