"use strict";
/** @file Types used in signatures of Cheerio methods. */
Object.defineProperty(exports, "__esModule", { value: true });//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/cheerio/dist/commonjs/types.js.map