/*! @azure/msal-node v5.1.1 2026-03-18 */
'use strict';
/* eslint-disable header/header */
const name = "@azure/msal-node";
const version = "5.1.1";

export { name, version };
//# sourceMappingURL=packageMetadata.mjs.map
