// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export const decompressResponsePolicyName = "decompressResponsePolicy";
/**
 * decompressResponsePolicy is not supported in the browser and attempting
 * to use it will raise an error.
 */
export function decompressResponsePolicy() {
    throw new Error("decompressResponsePolicy is not supported in browser environment");
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@typespec/ts-http-runtime/dist/browser/policies/decompressResponsePolicy.js.map