// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export * from "./concat.common.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@typespec/ts-http-runtime/dist/react-native/util/concat.js.map