export { AzureKeyCredential } from "./azureKeyCredential.js";
export { isKeyCredential } from "./keyCredential.js";
export { AzureNamedKeyCredential, isNamedKeyCredential, } from "./azureNamedKeyCredential.js";
export { AzureSASCredential, isSASCredential } from "./azureSASCredential.js";
export { isTokenCredential, } from "./tokenCredential.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@azure/core-auth/dist/react-native/index.js.map