// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { agentPolicyName as tspAgentPolicyName, agentPolicy as tspAgentPolicy, } from "@typespec/ts-http-runtime/internal/policies";
/**
 * Name of the Agent Policy
 */
export const agentPolicyName = tspAgentPolicyName;
/**
 * Gets a pipeline policy that sets http.agent
 */
export function agentPolicy(agent) {
    return tspAgentPolicy(agent);
}//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/e7fb5e96c0730b9deb70b33781f98e2f35975036/node_modules/@azure/core-rest-pipeline/dist/react-native/policies/agentPolicy.js.map