/*! @azure/msal-node v5.1.1 2026-03-18 */
'use strict';
/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
const missingTenantIdError = "missing_tenant_id_error";
const userTimeoutReached = "user_timeout_reached";
const invalidAssertion = "invalid_assertion";
const invalidClientCredential = "invalid_client_credential";
const deviceCodePollingCancelled = "device_code_polling_cancelled";
const deviceCodeExpired = "device_code_expired";
const deviceCodeUnknownError = "device_code_unknown_error";

export { deviceCodeExpired, deviceCodePollingCancelled, deviceCodeUnknownError, invalidAssertion, invalidClientCredential, missingTenantIdError, userTimeoutReached };
//# sourceMappingURL=ClientAuthErrorCodes.mjs.map
